package VMOMI::ClusterDasFdmAvailabilityState;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
